======================
All Overcloud Commands
======================

.. autoprogram-cliff:: openstack.tripleoclient.v2
   :command: overcloud *

==================
Container Commands
==================

.. autoprogram-cliff:: openstack.tripleoclient.v2
   :command: tripleo container *

.. autoprogram-cliff:: openstack.tripleoclient.v2
   :command: overcloud container image [!prep]*

===================
Undercloud Commands
===================

.. autoprogram-cliff:: openstack.tripleoclient.v2
   :command: undercloud *

===================
Standalone Commands
===================

.. autoprogram-cliff:: openstack.tripleoclient.v2
   :command: tripleo deploy

.. autoprogram-cliff:: openstack.tripleoclient.v2
   :command: tripleo upgrade

